A test function to work with elastic networks in future, be omitted so far
estimate.elnet(formula, response, data, family, alpha)marginal likelihood of the model
AIC model selection criterion
BIC model selection criterion
a vector of posterior modes of the parameters
a formula object for the model to be addressed
response in a formula
a data frame object containing variables and observations corresponding to the formula used
distribution of the response family object
regularization parameter in [0,1]
glmnet::glmnet